@@ -54,10 +54,6 @@ sub source {
     $self->tag('no-human-maintainers')
       if $is_list && !$self->processable->fields->exists('Uploaders');
 
-    $self->tag('papt-dmpt-merged')
-      if $maintainer =~ m{python-modules-team\@lists\.alioth\.debian\.org}
-      or $maintainer =~ m{python-apps-team\@lists\.alioth\.debian\.org};
-
     return;
 }
 
