@@ -37,8 +37,8 @@ with 'Lintian::Check';
 sub installable {
     my ($self) = @_;
 
-    my $pkg = $self->package;
-    my $type = $self->type;
+    my $pkg = $self->processable->name;
+    my $type = $self->processable->type;
     my $processable = $self->processable;
     my $group = $self->group;
 
@@ -129,7 +129,7 @@ sub check_udev_rules {
     return $retval;
 }
 
-sub files {
+sub visit_installed_files {
     my ($self, $file) = @_;
 
     return
